@@ -29,7 +29,12 @@ def search_comports():
         raise EnvironmentError("Unsupported platform")
 
     result = []
-    _logger.debug("Found %d ports.", len(ports))
+    n_ports = len(ports)
+    if n_ports == 1:
+        _logger.debug("Found %d accessible port.", n_ports)
+    else:
+        _logger.debug("Found %d accessible ports.", n_ports)
+
     for port in ports:
         try:
             s = serial.Serial(port)
@@ -37,12 +42,12 @@ def search_comports():
             result.append(port)
         except (OSError, serial.SerialException) as e:
             if "Permission" in str(e):
-                _logger.info("No permission to read %s", len(result))
+                _logger.info("No permission to read %s", port)
             pass
-    _logger.info("Found %d devices.", len(result))
+    n_detected_devices = len(result)
+    if n_detected_devices == 1:
+        _logger.info("%d accessible uart device.", n_detected_devices)
+    else:
+        _logger.info("%d accessible uart devices.", n_detected_devices)
 
     return result
-
-
-if __name__ == "__main__":
-    print(serial_ports())
