@@ -17,6 +17,7 @@ from pyftdi.usbtools import UsbTools, UsbToolsError
 from .i2controller import MUX
 from serial.tools import list_ports
 from ..core.i2controller import MmsSpiController as SpiController
+from ..core.i2controller import MmsI2cController as I2cController
 
 
 logging.getLogger("pyftdi").setLevel(logging.ERROR)
@@ -26,10 +27,11 @@ class Sensor:
     """
     Abstract sensor class
     """
+
     __name__ = None
     _units = {}
     _max_attempts = 5
-    _delay = 2E-2
+    _delay = 2e-2
     serial_number = None
     sensor_id = None
     ftdi_serial = None
@@ -52,13 +54,13 @@ class Sensor:
         Standard result output
         """
         return {
-            'object': 'DATA',
-            'sensor_type': self.__name__,
-            'error': True,
-            'serialno': self.serial_number,
-            'id': self.sensor_id,
-            'FTDIserial': self.ftdi_serial,
-            'values': {}
+            "object": "DATA",
+            "sensor_type": self.__name__,
+            "error": True,
+            "SENSORserial": self.serial_number,
+            "id": self.sensor_id,
+            "FTDIserial": self.ftdi_serial,
+            "values": {},
         }
 
     @staticmethod
@@ -69,12 +71,10 @@ class Sensor:
         :rtype: float
         """
         if len(arr) == 4:
-            struct_float = struct.pack('>BBBB', arr[0], arr[1], arr[2], arr[3])
-            float_value = struct.unpack('>f', struct_float)[0]
+            struct_float = struct.pack(">BBBB", arr[0], arr[1], arr[2], arr[3])
+            float_value = struct.unpack(">f", struct_float)[0]
         else:
-            raise ValueError(
-                    f"Incorrect length of arr. Expected 4 got {len(arr)}"
-                    )
+            raise ValueError(f"Incorrect length of arr. Expected 4 got {len(arr)}")
         return float_value
 
     @classmethod
@@ -114,8 +114,8 @@ class Sensor:
         float_value = None
         if len(arr) == 4:
             # read 4 element hex array to float following IEEE754
-            struct_float = struct.pack('>BBBB', arr[0], arr[1], arr[2], arr[3])
-            float_value = struct.unpack('>f', struct_float)[0]
+            struct_float = struct.pack(">BBBB", arr[0], arr[1], arr[2], arr[3])
+            float_value = struct.unpack(">f", struct_float)[0]
         return float_value
 
     def prepare_measurement(self):
@@ -132,11 +132,11 @@ class Sensor:
 
     def register(self):
         info = {}
-        info['identifier'] = self.__name__
-        info['serialnumber'] = self.serial_number
-        info['description'] = self.description
-        info['port'] = self.ftdi_serial
-        info['channel'] = []
+        info["identifier"] = self.__name__
+        info["serialnumber"] = self.serial_number
+        info["description"] = self.description
+        info["port"] = self.ftdi_serial
+        info["channel"] = []
         return info
 
     @property
@@ -149,14 +149,12 @@ class SPISensor(Sensor):
     """
     Standardized SPI sensor class
     """
+
     # On UM232H CS0 => D3
     _serial_mode = "SPI"
     device = None
 
-    def __init__(self,
-                 bus: 'MMS_SPIController',
-                 cs: int,
-                 sensor_id: str = None):
+    def __init__(self, bus: "SpiController", cs: int, sensor_id: str = None):
         self.cs = int(cs)
         self.bus = bus
         self.sensor_type = self.__name__
@@ -166,7 +164,7 @@ class SPISensor(Sensor):
 
     def default_data(self):
         data = super().default_data()
-        data['CS'] = self.cs
+        data["CS"] = self.cs
         return data
 
     def txrx(self, reg: int, val=None, readlen: int = 1):
@@ -197,10 +195,8 @@ class SPISensor(Sensor):
 
             except (I2cNackError, I2cIOError):
                 self._logger.error(
-                        "Communication failure. (%s/%s)",
-                        i,
-                        self._max_attempts
-                        )
+                    "Communication failure. (%s/%s)", i, self._max_attempts
+                )
                 i += 1
                 data = None
 
@@ -221,27 +217,29 @@ class SPISensor(Sensor):
                         UsbTools.flush_cache()
                         self.bus = SpiController(CS_MUX=mux)
                         self.bus.ftdi.open_from_url(url)
-                        self.bus.configure(
-                                url,
-                                frequency=frequency)
+                        self.bus.configure(url, frequency=frequency)
                         self._logger.info(
-                                "Opened new connection. (f=%d kHz)",
-                                int(self.bus._frequency / 1000.)
-                                )
+                            "Opened new connection. (f=%d kHz)",
+                            int(self.bus._frequency / 1000.0),
+                        )
                         break
                     except (FtdiError, UsbToolsError, ValueError):
                         attempt += 1
-                        self._logger.error("FTDI connection issue \
+                        self._logger.error(
+                            "FTDI connection issue \
                                             - Attempt (%s/%s)",
-                                           attempt,
-                                           self._max_attempts
-                                           )
+                            attempt,
+                            self._max_attempts,
+                        )
                     if attempt == self._max_attempts:
                         # if reconnection attempts failed the device
                         # is put to rest and will be asked again
                         attempt -= 1
-                        self._logger.error("Failed to reconnect. Wait %s seconds\
-                                before trying againg once.", sleeping_time)
+                        self._logger.error(
+                            "Failed to reconnect. Wait %s seconds\
+                                before trying againg once.",
+                            sleeping_time,
+                        )
                         time.sleep(sleeping_time)
                 return None
 
@@ -278,13 +276,14 @@ class I2CSensor(Sensor):
     """
     Generalized I2C sensor
     """
+
     _clk_stretch = True
     _serial_mode = "I2C"
     mux_port = 0
     mux = MUX(None, None)
     _SENSOR_ADDRESS = -1
 
-    def __init__(self, bus: 'MMS_I2CController', mux: 'MUX', mux_port: int):
+    def __init__(self, bus: "I2cController", mux: "MUX", mux_port: int):
         """
         Base class for all I2C Sensors
         :param bus: (core.i2controler.MMS_I2CController) sensor bus object
@@ -303,8 +302,8 @@ class I2CSensor(Sensor):
         Default I2C Sensor result data
         """
         data = super().default_data()
-        data['MUXaddress'] = self.mux.address
-        data['MUXport'] = self.mux_port
+        data["MUXaddress"] = self.mux.address
+        data["MUXport"] = self.mux_port
         return data
 
     def __str__(self):
@@ -378,18 +377,19 @@ class I2CSensor(Sensor):
 
     def info(self):
         if self.exists:
-            print(f"{self.ftdi_serial} | {self.mux.address} | \
-                    {self.mux_port} => found {self.__name__}")
-            return(
-                {
-                    'SENSORtype': self.__name__,
-                    'SENSORserial': self.serial_number,
-                    'FTDIserial': self.ftdi_serial,
-                    'MUXaddress': self.mux.address,
-                    'MUXport': self.mux_port,
-                    'units': self._units,
-                    'SENSORidentifier': ''
-                })
+            print(
+                f"{self.ftdi_serial} | {self.mux.address} | \
+                    {self.mux_port} => found {self.__name__}"
+            )
+            return {
+                "SENSORtype": self.__name__,
+                "SENSORserial": self.serial_number,
+                "FTDIserial": self.ftdi_serial,
+                "MUXaddress": self.mux.address,
+                "MUXport": self.mux_port,
+                "units": self._units,
+                "SENSORidentifier": "",
+            }
         return False
 
     def txrx(self, cmd, readlen=3):
@@ -411,24 +411,19 @@ class I2CSensor(Sensor):
             try:
                 if len(cmd) == 0:
                     data = self.mux.receive(
-                            self._SENSOR_ADDRESS,
-                            self.mux_port,
-                            readlength=readlen)
+                        self._SENSOR_ADDRESS, self.mux_port, readlength=readlen
+                    )
                 elif readlen == 0:
                     self.mux.send(self.mux_port, self._SENSOR_ADDRESS, cmd)
                 else:
-                    data = self.mux.exchange(self._SENSOR_ADDRESS,
-                                             self.mux_port,
-                                             cmd,
-                                             readlength=readlen
-                                             )
+                    data = self.mux.exchange(
+                        self._SENSOR_ADDRESS, self.mux_port, cmd, readlength=readlen
+                    )
                 break
             except (I2cNackError, I2cIOError):
                 self._logger.error(
-                        "Communication failure. (%s/%s)",
-                        i,
-                        self._max_attempts
-                        )
+                    "Communication failure. (%s/%s)", i, self._max_attempts
+                )
                 i += 1
                 data = None
 
@@ -448,27 +443,32 @@ class I2CSensor(Sensor):
                     try:
                         UsbTools.flush_cache()
                         self.bus.configure(
-                                self.bus.url,
-                                clockstretching=True,
-                                frequency=self.bus._frequency)
+                            self.bus.url,
+                            clockstretching=True,
+                            frequency=self.bus._frequency,
+                        )
                         self._logger.info(
-                                "Opened new connection. (f=%d kHz)",
-                                int(self.bus._frequency / 1000.)
-                                )
+                            "Opened new connection. (f=%d kHz)",
+                            int(self.bus._frequency / 1000.0),
+                        )
                         break
                     except (FtdiError, UsbToolsError, ValueError):
                         attempt += 1
-                        self._logger.error("FTDI connection issue \
+                        self._logger.error(
+                            "FTDI connection issue \
                                             - Attempt (%s/%s)",
-                                           attempt,
-                                           self._max_attempts
-                                           )
+                            attempt,
+                            self._max_attempts,
+                        )
                     if attempt == self._max_attempts:
                         # if reconnection attempts failed the device
                         # is put to rest and will be asked again
                         attempt -= 1
-                        self._logger.error("Failed to reconnect. Wait %s seconds\
-                                before trying againg once.", sleeping_time)
+                        self._logger.error(
+                            "Failed to reconnect. Wait %s seconds\
+                                before trying againg once.",
+                            sleeping_time,
+                        )
                         time.sleep(sleeping_time)
                 return None
 
@@ -479,14 +479,14 @@ class UARTSensor(Sensor):
     """
     Generalized UART sensor
     """
+
     _clk_stretch = True
     _serial_mode = "UART"
     port = None
 
-    def __init__(self, bus: 'MMS_UARTController'):
+    def __init__(self, bus):
         """
         Base class for all I2C Sensors
-        :param bus: (core.i2controler.MMS_UARTController) sensor bus object
         """
         self.bus = bus
         self._logger = logging.getLogger(self.__str__())
@@ -496,7 +496,7 @@ class UARTSensor(Sensor):
         Default COM Sensor result data
         """
         data = super().default_data()
-        data['Port'] = self.port
+        data["Port"] = self.port
         return data
 
     def __str__(self):
@@ -514,14 +514,13 @@ class UARTSensor(Sensor):
     def info(self):
         if self.exists:
             print(f"{self.port} > found {self.__name__}")
-            return(
-                {
-                    'SENSORtype': self.__name__,
-                    'SENSORserial': self.serial_number,
-                    'Port': self.port,
-                    'units': self._units,
-                    'SENSORidentifier': ''
-                })
+            return {
+                "SENSORtype": self.__name__,
+                "SENSORserial": self.serial_number,
+                "Port": self.port,
+                "units": self._units,
+                "SENSORidentifier": "",
+            }
         return False
 
     def txrx(self, cmd, readlen=3, t_wait=0.1):
@@ -547,4 +546,3 @@ class UARTSensor(Sensor):
 
     def close_port(self):
         self.ser.close()
-
